@@ -1,4 +1,4 @@
-CREATE OR REPLACE FUNCTION @extschema@.create_parent(
+CREATE FUNCTION @extschema@.create_parent(
     p_parent_table text
     , p_control text
     , p_type text
@@ -36,6 +36,7 @@ v_higher_parent_control         text;
 v_higher_parent_schema          text := split_part(p_parent_table, '.', 1);
 v_higher_parent_table           text := split_part(p_parent_table, '.', 2);
 v_id_interval                   bigint;
+v_inherit_privileges            boolean := false;
 v_job_id                        bigint;
 v_jobmon_schema                 text;
 v_last_partition_created        boolean;
@@ -116,6 +117,10 @@ AND a.attname = p_control::name;
 SELECT general_type, exact_type INTO v_control_type, v_control_exact_type
 FROM @extschema@.check_control_type(v_parent_schema, v_parent_tablename, p_control);
 
+IF v_control_type IS NULL THEN
+    RAISE EXCEPTION 'pg_partman only supports partitioning of data types that are integer or date/timestamp. Supplied column is of type %', v_control_exact_type;
+END IF;
+
 IF (p_epoch <> 'none' AND v_control_type <> 'id') THEN
     RAISE EXCEPTION 'p_epoch can only be used with an integer based control column and does not work for native partitioning';
 END IF;
@@ -192,7 +197,7 @@ IF p_type = 'native' THEN
             END IF;
     END IF;
 
-ELSE
+ELSE -- if not native 
 
     IF current_setting('server_version_num')::int >= 100000 THEN
         SELECT p.partstrat INTO v_partstrat
@@ -207,7 +212,8 @@ ELSE
         RAISE EXCEPTION 'Given parent table has been set up with native partitioning therefore cannot be used with pg_partman''s other partitioning types. Either recreate table non-native or set the type argument to ''native''';
     END IF;
 
-END IF;
+END IF; -- end if "native" check
+
 
 IF p_publications IS NOT NULL THEN
     IF current_setting('server_version_num')::int < 100000 THEN
@@ -226,6 +232,14 @@ IF p_publications IS NOT NULL THEN
     END LOOP;
 END IF;
 
+-- Only inherit parent ownership/privileges on non-native sets by default
+-- This is false by default so initial partition set creation doesn't require superuser.
+IF p_type = 'native' THEN
+    v_inherit_privileges = false;
+ELSE
+    v_inherit_privileges  = true;
+END IF;
+
 SELECT current_setting('search_path') INTO v_old_search_path;
 IF p_jobmon THEN
     SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
@@ -277,6 +291,8 @@ FOR v_row IN
         , sub_upsert
         , sub_trigger_return_null
         , sub_template_table
+        , sub_inherit_privileges
+        , sub_constraint_valid
     FROM @extschema@.part_config_sub a
     JOIN sibling_children b on a.sub_parent = b.tablename LIMIT 1
 LOOP
@@ -301,7 +317,9 @@ LOOP
         , sub_trigger_exception_handling
         , sub_upsert
         , sub_trigger_return_null
-        , sub_template_table)
+        , sub_template_table
+        , sub_inherit_privileges
+        , sub_constraint_valid)
     VALUES (
         p_parent_table
         , v_row.sub_partition_type
@@ -323,8 +341,15 @@ LOOP
         , v_row.sub_trigger_exception_handling
         , v_row.sub_upsert
         , v_row.sub_trigger_return_null
-        , v_row.sub_template_table);
-    
+        , v_row.sub_template_table
+        , v_row.sub_inherit_privileges
+        , v_row.sub_constraint_valid);
+
+    -- Set this equal to sibling configs so that newly created child table 
+    -- privileges are set properly below during initial setup.
+    -- This setting is special because it applies immediately to the new child 
+    -- tables of a given parent, not just during maintenance like most other settings.
+    v_inherit_privileges = v_row.sub_inherit_privileges;
 END LOOP;
 
 IF v_control_type = 'time' OR (v_control_type = 'id' AND p_epoch <> 'none') THEN
@@ -436,7 +461,8 @@ IF v_control_type = 'time' OR (v_control_type = 'id' AND p_epoch <> 'none') THEN
         , upsert
         , trigger_return_null
         , template_table
-        , publications)
+        , publications
+        , inherit_privileges)
     VALUES (
         p_parent_table
         , p_type
@@ -452,7 +478,8 @@ IF v_control_type = 'time' OR (v_control_type = 'id' AND p_epoch <> 'none') THEN
         , p_upsert
         , p_trigger_return_null
         , v_template_schema||'.'||v_template_tablename
-        , p_publications); 
+        , p_publications
+        , v_inherit_privileges); 
 
     RAISE DEBUG 'create_parent: v_partition_time_array: %', v_partition_time_array;
 
@@ -590,7 +617,8 @@ IF v_control_type = 'id' AND p_epoch = 'none' THEN
         , upsert
         , trigger_return_null
         , template_table
-        , publications)
+        , publications
+        , inherit_privileges)
     VALUES (
         p_parent_table
         , p_type
@@ -604,7 +632,8 @@ IF v_control_type = 'id' AND p_epoch = 'none' THEN
         , p_upsert
         , p_trigger_return_null
         , v_template_schema||'.'||v_template_tablename
-        , p_publications); 
+        , p_publications
+        , v_inherit_privileges); 
 
     v_last_partition_created := @extschema@.create_partition_id(p_parent_table, v_partition_id_array, false);
 
@@ -667,10 +696,16 @@ IF p_type = 'native' AND current_setting('server_version_num')::int >= 110000 TH
 
     v_default_partition := @extschema@.check_name_length(v_parent_tablename, '_default', FALSE);
     v_sql := 'CREATE'; 
+
+    -- Left this here as reminder to revisit once native figures out how it is handling changing unlogged stats
+    -- Currently handed via template table below
+    /* 
     IF v_unlogged = 'u' THEN
-        v_sql := v_sql ||' UNLOGGED';
+         v_sql := v_sql ||' UNLOGGED';
     END IF;
-    -- Same INCLUDING list is used in create_partition_*()
+    */
+
+    -- Same INCLUDING list is used in create_partition_*(). INDEXES is handled when partition is attached if it's supported.
     v_sql := v_sql || format(' TABLE %I.%I (LIKE %I.%I INCLUDING DEFAULTS INCLUDING CONSTRAINTS INCLUDING STORAGE INCLUDING COMMENTS)'
         , v_parent_schema, v_default_partition, v_parent_schema, v_parent_tablename);
     EXECUTE v_sql;
@@ -678,12 +713,14 @@ IF p_type = 'native' AND current_setting('server_version_num')::int >= 110000 TH
         , v_parent_schema, v_parent_tablename, v_parent_schema, v_default_partition);
     EXECUTE v_sql;
 
-    IF v_parent_tablespace IS NOT NULL THEN
+    IF current_setting('server_version_num')::int >= 120000 AND v_parent_tablespace IS NOT NULL THEN
+        -- Tablespace managed via inherit_template_properties() call below if PG11 or earliser
         EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_default_partition, v_parent_tablespace);
     END IF;
 
-    -- NOTE: Privileges currently not automatically inherited for native
-    PERFORM @extschema@.apply_privileges(v_parent_schema, v_parent_tablename, v_parent_schema, v_default_partition, v_job_id);
+    -- Manage template inherited properies
+    PERFORM @extschema@.inherit_template_properties(p_parent_table, v_parent_schema, v_default_partition);
+
 END IF;
 
 IF p_type <> 'native' THEN
