@@ -17,6 +17,7 @@ v_epoch                         text;
 v_exists                        smallint;
 v_grantees                      text[];
 v_hasoids                       boolean;
+v_inherit_privileges            boolean;
 v_inherit_fk                    boolean;
 v_job_id                        bigint;
 v_jobmon                        boolean;
@@ -68,6 +69,7 @@ SELECT partition_type
     , datetime_string
     , template_table
     , publications
+    , inherit_privileges
 INTO v_partition_type
     , v_control
     , v_partition_interval
@@ -77,6 +79,7 @@ INTO v_partition_type
     , v_datetime_string
     , v_template_table
     , v_publications
+    , v_inherit_privileges
 FROM @extschema@.part_config
 WHERE parent_table = p_parent_table;
 
@@ -169,15 +172,19 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
                                                 , v_partition_timestamp_end-'1sec'::interval));
     END IF;
 
+    v_sql := 'CREATE';
+
+    -- As of PG12, the unlogged/logged status of a native parent table cannot be changed via an ALTER TABLE in order to affect its children.
+    -- As of v4.2x, the unlogged state will be managed via the template table    
     SELECT relpersistence INTO v_unlogged 
     FROM pg_catalog.pg_class c
     JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
     WHERE c.relname = v_parent_tablename::name
     AND n.nspname = v_parent_schema::name;
-    v_sql := 'CREATE';
-    IF v_unlogged = 'u' THEN
+    IF v_unlogged = 'u' and v_partition_type != 'native'  THEN
         v_sql := v_sql || ' UNLOGGED';
     END IF;
+
     -- Close parentheses on LIKE are below due to differing requirements of native subpartitioning
     -- Same INCLUDING list is used in create_parent()
     v_sql := v_sql || format(' TABLE %I.%I (LIKE %I.%I INCLUDING DEFAULTS INCLUDING CONSTRAINTS INCLUDING STORAGE INCLUDING COMMENTS '
@@ -190,32 +197,41 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
     FROM @extschema@.part_config_sub 
     WHERE sub_parent = p_parent_table;
     IF v_sub_partition_type = 'native' THEN
-        -- NOTE: Need to handle this differently when index inheritance is supported natively
-        -- Cannot include indexes since they cannot exist on native parents
+        -- INCLUDING INDEXES isn't necessary for native partitioning. It isn't supported in v10 and 
+	--   for v11+ index inheritance is automatically handled when the partition is attached
         v_sql := v_sql || format(') PARTITION BY RANGE (%I) ', v_sub_control);
     ELSE
         v_sql := v_sql || format(' INCLUDING INDEXES) ', v_sub_control);
     END IF;
 
-    SELECT relhasoids INTO v_hasoids 
-    FROM pg_catalog.pg_class c
-    JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
-    WHERE c.relname = v_parent_tablename::name
-    AND n.nspname = v_parent_schema::name;
-    IF v_hasoids IS TRUE THEN
-        v_sql := v_sql || ' WITH (OIDS)';
+    IF current_setting('server_version_num')::int < 120000 THEN
+        -- column removed from pgclass in pg12
+        SELECT relhasoids INTO v_hasoids 
+        FROM pg_catalog.pg_class c
+        JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
+        WHERE c.relname = v_parent_tablename::name
+        AND n.nspname = v_parent_schema::name;
+        IF v_hasoids IS TRUE THEN
+            v_sql := v_sql || ' WITH (OIDS)';
+        END IF;
     END IF;
+
     IF p_debug THEN
         RAISE NOTICE 'create_partition_time v_sql: %', v_sql;
     END IF;
     EXECUTE v_sql;
 
-    IF v_parent_tablespace IS NOT NULL THEN
-        EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_partition_name, v_parent_tablespace);
-    END IF;
 
     IF v_partition_type = 'native' THEN
 
+        IF current_setting('server_version_num')::int >= 120000 THEN
+            -- PG12 fixed tablespace marking on the parent of a native partition set
+            -- Versions older than 12 handle tablespace setting via inherit_template_properties() call below
+            IF v_parent_tablespace IS NOT NULL THEN
+                EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_partition_name, v_parent_tablespace);
+            END IF;
+        END IF;
+
         IF v_template_table IS NOT NULL THEN
             PERFORM @extschema@.inherit_template_properties(p_parent_table, v_parent_schema, v_partition_name);
         END IF;
@@ -257,7 +273,12 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
                 , v_partition_timestamp_start
                 , v_partition_timestamp_end);
         END IF;
-    ELSE
+    ELSE -- non-native
+
+        IF v_parent_tablespace IS NOT NULL THEN
+            EXECUTE format('ALTER TABLE %I.%I SET TABLESPACE %I', v_parent_schema, v_partition_name, v_parent_tablespace);
+        END IF;
+
         -- Non-native always gets time-based constraint
         EXECUTE format('ALTER TABLE %I.%I ADD CONSTRAINT %I CHECK (%s >= %L AND %4$s < %6$L)'
             , v_parent_schema
@@ -309,8 +330,10 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
 
     END IF; -- end native check
 
-    -- NOTE: Privileges currently not automatically inherited for native
-    PERFORM @extschema@.apply_privileges(v_parent_schema, v_parent_tablename, v_parent_schema, v_partition_name, v_job_id);
+    -- NOTE: Privileges not automatically inherited for native. Only do so if config flag is set
+    IF v_partition_type != 'native' OR (v_partition_type = 'native' AND v_inherit_privileges = TRUE) THEN
+        PERFORM @extschema@.apply_privileges(v_parent_schema, v_parent_tablename, v_parent_schema, v_partition_name, v_job_id);
+    END IF;
 
     IF v_jobmon_schema IS NOT NULL THEN
         PERFORM update_step(v_step_id, 'OK', 'Done');
@@ -338,6 +361,8 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
             , sub_jobmon
             , sub_trigger_exception_handling
             , sub_template_table
+            , sub_inherit_privileges
+            , sub_constraint_valid
         FROM @extschema@.part_config_sub
         WHERE sub_parent = p_parent_table
     LOOP
@@ -380,6 +405,8 @@ FOREACH v_time IN ARRAY p_partition_times LOOP
             , optimize_constraint = v_row.sub_optimize_constraint
             , infinite_time_partitions = v_row.sub_infinite_time_partitions
             , trigger_exception_handling = v_row.sub_trigger_exception_handling
+            , inherit_privileges = v_row.sub_inherit_privileges
+            , constraint_valid = v_row.sub_constraint_valid
         WHERE parent_table = v_parent_schema||'.'||v_partition_name;
 
     END LOOP; -- end sub partitioning LOOP
@@ -449,4 +476,3 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
-
