@@ -135,8 +135,9 @@ WHERE schemaname = split_part(p_parent_table, '.', 1)::name
 AND tablename = split_part(p_parent_table, '.', 2)::name;
 
 -- Loop through child tables of the given parent
+-- Must go in ascending order to avoid dropping what may be the "last" partition in the set after dropping tables that match retention period
 FOR v_row IN 
-    SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(p_parent_table, 'DESC')
+    SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(p_parent_table, 'ASC')
 LOOP
     -- pull out datetime portion of partition's tablename to make the next one
      SELECT child_start_time INTO v_partition_timestamp FROM @extschema@.show_partition_info(v_row.partition_schemaname||'.'||v_row.partition_tablename
@@ -163,18 +164,22 @@ LOOP
                                                 , v_row.partition_tablename
                                                 , p_parent_table));
         END IF;
-        IF v_partition_type = 'native' THEN
-            EXECUTE format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
-                , v_parent_schema
-                , v_parent_tablename
-                , v_row.partition_schemaname
-                , v_row.partition_tablename);
-        ELSE
-            EXECUTE format('ALTER TABLE %I.%I NO INHERIT %I.%I'
-                    , v_row.partition_schemaname
-                    , v_row.partition_tablename
+        IF v_retention_keep_table = true THEN
+            -- No need to detach partition before dropping since it's going away anyway
+            -- Avoids issue of FKs not allowing detachment (Github Issue #294).
+            IF v_partition_type = 'native' THEN
+                EXECUTE format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
                     , v_parent_schema
-                    , v_parent_tablename);
+                    , v_parent_tablename
+                    , v_row.partition_schemaname
+                    , v_row.partition_tablename);
+            ELSE
+                EXECUTE format('ALTER TABLE %I.%I NO INHERIT %I.%I'
+                        , v_row.partition_schemaname
+                        , v_row.partition_tablename
+                        , v_parent_schema
+                        , v_parent_tablename);
+            END IF;
         END IF;
         IF v_partition_type = 'time-custom' THEN
             DELETE FROM @extschema@.custom_time_partitions WHERE parent_table = p_parent_table AND child_table = v_row.partition_schemaname||'.'||v_row.partition_tablename;
@@ -182,6 +187,7 @@ LOOP
         IF v_jobmon_schema IS NOT NULL THEN
             PERFORM update_step(v_step_id, 'OK', 'Done');
         END IF;
+
         IF v_retention_schema IS NULL THEN
             IF v_retention_keep_table = false THEN
                 IF v_jobmon_schema IS NOT NULL THEN
@@ -192,40 +198,44 @@ LOOP
                     PERFORM update_step(v_step_id, 'OK', 'Done');
                 END IF;
             ELSIF v_retention_keep_index = false THEN
-                FOR v_index IN 
-                    WITH child_info AS (
-                        SELECT c1.oid
-                        FROM pg_catalog.pg_class c1
-                        JOIN pg_catalog.pg_namespace n1 ON c1.relnamespace = n1.oid
-                        WHERE c1.relname = v_row.partition_tablename::name
-                        AND n1.nspname = v_row.partition_schemaname::name
-                    )
-                    SELECT c.relname as name
-                        , con.conname
-                    FROM pg_catalog.pg_index i
-                    JOIN pg_catalog.pg_class c ON i.indexrelid = c.oid
-                    LEFT JOIN pg_catalog.pg_constraint con ON i.indexrelid = con.conindid
-                    JOIN child_info ON i.indrelid = child_info.oid
-                LOOP
-                    IF v_jobmon_schema IS NOT NULL THEN
-                        v_step_id := add_step(v_job_id, format('Drop index %s from %s.%s'
-                                                            , v_index.name
-                                                            , v_row.partition_schemaname
-                                                            , v_row.partition_tablename));
-                    END IF;
-                    IF v_index.conname IS NOT NULL THEN
-                        EXECUTE format('ALTER TABLE %I.%I DROP CONSTRAINT %I'
-                                        , v_row.partition_schemaname
-                                        , v_row.partition_tablename
-                                        , v_index.conname);
-                    ELSE
-                        EXECUTE format('DROP INDEX %I.%I', v_parent_schema, v_index.name);
-                    END IF;
-                    IF v_jobmon_schema IS NOT NULL THEN
-                        PERFORM update_step(v_step_id, 'OK', 'Done');
-                    END IF;
-                END LOOP;
-            END IF;
+                IF v_partition_type = 'partman' OR 
+                       ( v_partition_type = 'native' AND  current_setting('server_version_num')::int < 110000) THEN
+                    -- Cannot drop child indexes on native partition sets in PG11+
+                    FOR v_index IN 
+                        WITH child_info AS (
+                            SELECT c1.oid
+                            FROM pg_catalog.pg_class c1
+                            JOIN pg_catalog.pg_namespace n1 ON c1.relnamespace = n1.oid
+                            WHERE c1.relname = v_row.partition_tablename::name
+                            AND n1.nspname = v_row.partition_schemaname::name
+                        )
+                        SELECT c.relname as name
+                            , con.conname
+                        FROM pg_catalog.pg_index i
+                        JOIN pg_catalog.pg_class c ON i.indexrelid = c.oid
+                        LEFT JOIN pg_catalog.pg_constraint con ON i.indexrelid = con.conindid
+                        JOIN child_info ON i.indrelid = child_info.oid
+                    LOOP
+                        IF v_jobmon_schema IS NOT NULL THEN
+                            v_step_id := add_step(v_job_id, format('Drop index %s from %s.%s'
+                                                                , v_index.name
+                                                                , v_row.partition_schemaname
+                                                                , v_row.partition_tablename));
+                        END IF;
+                        IF v_index.conname IS NOT NULL THEN
+                            EXECUTE format('ALTER TABLE %I.%I DROP CONSTRAINT %I'
+                                            , v_row.partition_schemaname
+                                            , v_row.partition_tablename
+                                            , v_index.conname);
+                        ELSE
+                            EXECUTE format('DROP INDEX %I.%I', v_parent_schema, v_index.name);
+                        END IF;
+                        IF v_jobmon_schema IS NOT NULL THEN
+                            PERFORM update_step(v_step_id, 'OK', 'Done');
+                        END IF;
+                    END LOOP;
+                END IF; -- end native/11 check 
+            END IF; -- end v_retention_keep_index IF
         ELSE -- Move to new schema
             IF v_jobmon_schema IS NOT NULL THEN
                 v_step_id := add_step(v_job_id, format('Moving table %s.%s to schema %s'
@@ -285,3 +295,4 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
+
