@@ -95,10 +95,13 @@ IF v_control_type = 'time' OR (v_control_type = 'id' AND v_epoch <> 'none') THEN
                     child_start_time := to_timestamp(v_year || '-07-01', 'YYYY-MM-DD');
                 WHEN v_quarter = '4' THEN
                     child_start_time := to_timestamp(v_year || '-10-01', 'YYYY-MM-DD');
+                ELSE
+                    -- handle case when partition name did not use "q" convetion
+                    child_start_time := to_timestamp(v_suffix, v_datetime_string);
             END CASE;
         END IF;
 
-        child_end_time := (child_start_time + v_partition_interval::interval) - '1 second'::interval;
+        child_end_time := (child_start_time + v_partition_interval::interval);
 
 ELSIF v_control_type = 'id' THEN
 
@@ -118,3 +121,4 @@ RETURN;
 END
 $$;
 
+
