@@ -46,10 +46,22 @@ static volatile sig_atomic_t got_sigterm = false;
 /* GUC variables */
 static int pg_partman_bgw_interval = 3600; // Default hourly
 static char *pg_partman_bgw_role = "postgres"; // Default to postgres role
+
+// Do not analyze by default on PG11+
+#if (PG_VERSION_NUM >= 110000)
+static char *pg_partman_bgw_analyze = "off";
+#else
 static char *pg_partman_bgw_analyze = "on";
+#endif
+
 static char *pg_partman_bgw_jobmon = "on";
 static char *pg_partman_bgw_dbname = NULL;
 
+#if (PG_VERSION_NUM < 100500)
+static bool (*split_function_ptr)(char *, char, List **) = &SplitIdentifierString;
+#else
+static bool (*split_function_ptr)(char *, char, List **) = &SplitGUCList;
+#endif
 
 /*
  * Signal handler for SIGTERM
@@ -106,6 +118,18 @@ _PG_init(void)
                             NULL,
                             NULL);
 
+    #if (PG_VERSION_NUM >= 110000)
+    DefineCustomStringVariable("pg_partman_bgw.analyze",
+                            "Whether to run an analyze on a partition set whenever a new partition is created during run_maintenance(). Set to 'on' to send TRUE (default). Set to 'off' to send FALSE.",
+                            NULL,
+                            &pg_partman_bgw_analyze,
+                            "off",
+                            PGC_SIGHUP,
+                            0,
+                            NULL,
+                            NULL,
+                            NULL);
+    #else
     DefineCustomStringVariable("pg_partman_bgw.analyze",
                             "Whether to run an analyze on a partition set whenever a new partition is created during run_maintenance(). Set to 'on' to send TRUE (default). Set to 'off' to send FALSE.",
                             NULL,
@@ -116,6 +140,7 @@ _PG_init(void)
                             NULL,
                             NULL,
                             NULL);
+    #endif  
 
     DefineCustomStringVariable("pg_partman_bgw.dbname",
                             "CSV list of specific databases in the cluster to run pg_partman BGW on. This setting is not required and when not set, pg_partman will dynamically figure out which ones to run on. If set, forces the BGW to only run on these specific databases and never any others. Recommend leaving this unset unless necessary.",
@@ -246,7 +271,7 @@ void pg_partman_bgw_main(Datum main_arg) {
         if (pg_partman_bgw_dbname != NULL) {
             rawstring = pstrdup(pg_partman_bgw_dbname);
             // Parse string into list of identifiers 
-            if (!SplitIdentifierString(rawstring, ',', &elemlist)) {
+            if (!(*split_function_ptr)(rawstring, ',', &elemlist)) {
                 // syntax error in list 
                 pfree(rawstring);
                 list_free(elemlist);
@@ -377,7 +402,7 @@ void pg_partman_bgw_run_maint(Datum arg) {
     rawstring = pstrdup(pg_partman_bgw_dbname);
     elog(DEBUG1, "GUC rawstring copy: %s", rawstring);
     // Parse string into list of identifiers 
-    if (!SplitIdentifierString(rawstring, ',', &elemlist)) {
+    if (!(*split_function_ptr)(rawstring, ',', &elemlist)) {
         // syntax error in list 
         pfree(rawstring);
         list_free(elemlist);
