@@ -29,7 +29,7 @@ CREATE UNIQUE INDEX ON partman_test.time_taptest_table_template (col2) TABLESPAC
 
 SELECT create_parent('partman_test.time_taptest_table', 'col3', 'native', 'daily', p_template_table := 'partman_test.time_taptest_table_template');
 
-SELECT has_partition('partman_test', 'time_taptest_table', 'Check that time_taptest_table is natively partitioned');
+SELECT is_partitioned('partman_test', 'time_taptest_table', 'Check that time_taptest_table is natively partitioned');
 SELECT has_table('partman_test', 'time_taptest_table_template', 'Check template table was created');
 
 INSERT INTO partman_test.time_taptest_table (col1, col2, col3) VALUES (generate_series(1,10), 'stuff'||generate_series(1,10), CURRENT_TIMESTAMP);
